@@ -49,7 +49,7 @@
 
 #define GWC_VERSION_MAJOR 0
 #define GWC_VERSION_MINOR 22
-#define VERSION "0.22-04"
+#define VERSION "0.22-05"
 #define GWC_POINT_HANDLE 0x01
 #define SBW  128	/* Sample Block Width, the number of audio samples summarized in one block  */
 #define PROGRESS_UPDATE_INTERVAL 0.5	/* update status bar every 1/2  second on long edit operations */
@@ -185,12 +185,12 @@ typedef struct {
     int ready ;
 } DENOISE_DATA ;
 
-gchar *tmpdir;
-gchar *CLIPBOARD_FILE ;
+extern gchar *tmpdir;
+extern gchar *CLIPBOARD_FILE ;
 
 void print_denoise(char *header, struct denoise_prefs *pDnprefs) ;
 
-GtkWidget *main_window;
+extern GtkWidget *main_window;
 
 GtkWidget *add_number_entry_with_label(char *entry_text, char *label_text, GtkWidget *table, int row) ;
 GtkWidget *add_number_entry_with_label_int(int value, char *label_text, GtkWidget *table, int row) ;
@@ -251,6 +251,7 @@ void load_denoise_preferences(void) ;
 void load_mp3_encoding_preferences(void);
 void load_mp3_simple_encoding_preferences(void);
 void load_ogg_encoding_preferences(void);
+void load_reverb_preferences(void);
 int load_sample_block_data(struct sound_prefs *p) ;
 void main_redraw(int cursor_flag, int redraw_data) ;
 void mark_songs(GtkWidget * widget, gpointer data) ;
@@ -278,7 +279,8 @@ void read_sample_block(struct sample_block *sb, struct sound_prefs *p, long bloc
 int  read_wavefile_data(long left[], long right[], long first, long last) ;
 void redraw(struct view *v, struct sound_prefs *p, GtkWidget *canvas, int cursor_flag, int redraw_data, int sonogram_flag) ;
 void rescan_sample_buffer(struct sound_prefs *p) ;
-void reverb_audio(struct sound_prefs *p, long first, long last, int channel_mask) ;
+void remove_extension(char* s) ;
+int reverb_audio(struct sound_prefs *p, long first, long last, int channel_mask) ;
 int  reverb_dialog(struct sound_prefs current, struct view *) ;
 int  sample_to_pixel(struct view *v, long sample) ;
 void save_cdrdao_tocs(GtkWidget * widget, gpointer data) ;
