@@ -39,8 +39,8 @@ char *cdtext_data = NULL;
 
 /* The file selection widget and the string to store the chosen filename */
 
-GtkWidget *file_selector;
-gchar *selected_filename;
+extern GtkWidget *file_selector;
+extern gchar *selected_filename;
 gchar save_cdrdao_toc_filename[PATH_MAX+1];
 extern long num_song_markers, song_markers[] ;
 extern gchar wave_filename[] ;
@@ -186,7 +186,7 @@ void cdrdao_toc_info(char *filename)
 	FILE *toc;
 	toc = fopen(filename,"w");
 	if (toc == NULL) {
-	   snprintf(buf, sizeof(buf), "Unable to open %s: %s", filename, strerror(errno));
+	   snprintf(buf, sizeof(buf), "Cannot write to %s: %s", filename, strerror(errno));
 	   warning(buf);
 	} else {
 	   int found_text = 0;
@@ -231,7 +231,6 @@ void cdrdao_toc_info(char *filename)
 	   } else {
 	      new_cdtext = NULL;
 	   }
-
 	   for (j = 0; j < num_song_markers+(1-use_song_marker_pairs); j += 1+use_song_marker_pairs) {
 	      long end;
 	      int j1 = j+1 ;
@@ -245,7 +244,7 @@ void cdrdao_toc_info(char *filename)
 		      length = song_markers[j+1] - start + 1 ;
 		  } else {
 		      /* no last song marker in last pair, assume end of audio for end of last track */
-		      length = (prefs.n_samples-1) - start + 1 ;
+		      length = (prefs.n_samples-1) - start + 1 ; // the +1 and -1 cancel each other out, but this makes the logic clearer, and the optimizer will figure it out...
 		  }
 	      } else {
 		  if (j == 0) {
@@ -253,7 +252,7 @@ void cdrdao_toc_info(char *filename)
 		    length = song_markers[j] - start + 1 ;
 		  } else if (j == num_song_markers) {
 		    start = song_markers[j-1] ;
-		    length = (prefs.n_samples-1) - start + 1 ;
+		    length = (prefs.n_samples-1) - start + 1 ; // the +1 and -1 cancel each other out, but this makes the logic clearer, and the optimizer will figure it out...
 		  } else {
 		    start = song_markers[j-1] ;
 		    length = song_markers[j] - start + 1 ;
@@ -313,7 +312,6 @@ void store_cdrdao_toc(gpointer user_data)
 	l = strlen(save_cdrdao_toc_filename) ;
 
 	d_print("Save cdrdao_toc to %s\n", save_cdrdao_toc_filename) ;
-
 	cdrdao_toc_info(save_cdrdao_toc_filename) ;
 
     } else {
@@ -324,7 +322,7 @@ void store_cdrdao_toc(gpointer user_data)
 
 void save_cdrdao_toc(GtkWidget * widget, gpointer data)
 {
-   char tmppath[PATH_MAX+6];
+   char tmppath[PATH_MAX+6]; //Why +6?
    GtkFileFilter * ff, * ffa;
 
    if (num_song_markers == 0) {
@@ -332,16 +330,17 @@ void save_cdrdao_toc(GtkWidget * widget, gpointer data)
    } else {
 	strcpy(tmppath, wave_filename);
 
-	/* Create the selector */
-	file_selector =
-	    gtk_file_chooser_dialog_new("Filename to save cdrdao toc to:",
+    /* Create the selector */
+    file_selector =
+        gtk_file_chooser_dialog_new("Filename to save cdrdao toc to:",
                                         GTK_WINDOW(main_window),
                                         GTK_FILE_CHOOSER_ACTION_SAVE,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                         GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
                                         NULL);
 
-	bcopy(".toc", strrchr(tmppath, '.'), 4);
+    remove_extension(tmppath) ;
+    strcat(tmppath, ".toc");
 	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER
 					  (file_selector), basename(tmppath));
 	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER
