@@ -43,12 +43,12 @@ void load_reverb_preferences(void)
 
     // We should probably have a separate test for each preference...
     if (g_key_file_has_group(key_file, "reverb_params") == TRUE) {
-	strcpy(reverb_method_name, g_key_file_get_string(key_file, "reverb_params", "reverb_method_name", NULL));
+        strcpy(reverb_method_name, g_key_file_get_string(key_file, "reverb_params", "reverb_method_name", NULL));
         wet_level = g_key_file_get_double(key_file, "reverb_params", "wet_level", NULL);
         dry_level = g_key_file_get_double(key_file, "reverb_params", "dry_level", NULL);
         decay = g_key_file_get_double(key_file, "reverb_params", "decay", NULL);
     } else {
-        // Not sure why this is set here rather than declared above like the other three preferences...
+        // Not sure why this is set here rather than the default being declared above like the other three preferences...
 	strcpy(reverb_method_name, "Ambience (Thick) - HD") ;
     }
 
@@ -68,20 +68,21 @@ void save_reverb_preferences(void)
 }
 
 
-void reverb_audio(struct sound_prefs *p, long first, long last, int channel_mask)
+int reverb_audio(struct sound_prefs *p, long first, long last, int channel_mask)
 {
     float left[BUFSIZE], right[BUFSIZE] ;
     reverb_audio_sample_t left_out[BUFSIZE], right_out[BUFSIZE] ;
     long current, i ;
     int loops = 0 ;
-
     current = first ;
 
     push_status_text("TAP Reverb audio") ;
     update_progress_bar(0.0,PROGRESS_UPDATE_INTERVAL,TRUE) ;
 
-    reverb_setup(p->rate, decay, wet_level, dry_level, reverb_method_name) ;
-
+    int rset = reverb_setup(p->rate, decay, wet_level, dry_level, reverb_method_name) ;
+    if (rset == 1) {
+        return 1 ;
+    }
 
     {
 
@@ -125,6 +126,7 @@ void reverb_audio(struct sound_prefs *p, long first, long last, int channel_mask
     pop_status_text() ;
 
     main_redraw(FALSE, TRUE) ;
+    return 0 ;
 }
 
 /* If we come here, then the user has selected a row in the list. */
